-- TitanWardrobe 1.0

function Wardrobe.TitanPanelButton_OnLoad()
	
	if ( IsAddOnLoaded("Titan") ) then
		-- register the plugin
		this.registry = {
			id = WARDROBE_TITAN_ID,
			menuText = WARDROBE_TITAN_ID,
			buttonTextFunction = "Wardrobe_TitanPanelButton_GetButtonText",
			tooltipTitle = WARDROBE_TITAN_BUTTON_TEXT,
			tooltipTextFunction = "Wardrobe_TitanPanelButton_GetTooltipText",
			icon = "Interface\\AddOns\\Wardrobe\\Images\\WardrobeTitan",
			iconWidth = 16,
			savedVariables = {
				ShowMinimapIcon = 1,
				ShowIcon = 1,
				ShowLabelText = TITAN_NIL,
				ShowColoredText = 1,
				SmallMenu = 1,
			}
		};
		if (Chronos) then
			this:RegisterEvent("UNIT_INVENTORY_CHANGED");
		else
			this.registry.frequency = 1;
		end
		
		TitanPanelButton_OnLoad();
	end
end

function Wardrobe.TitanPanelButton_OnEvent(event)
	Chronos.scheduleByName("WardrobeTitanUpdate", .2, function() TitanPanelButton_UpdateButton(WARDROBE_TITAN_ID) end);
end

function Wardrobe.TitanPanelButton_GetButtonText(id)

	local labelText = nil;
	local outfitText = nil;
	local curOutfit = nil;

	-- display the label if the user has selected
	if (TitanGetVar(WARDROBE_TITAN_ID, "ShowLabelText")) then
		labelText = WARDROBE_TITAN_BUTTON_TEXT;
	end
	
	-- get any active outfits
	Wardrobe.CheckForOurWardrobeID();
	local activeOutfitList = Wardrobe.DetermineActiveOutfit();
	
	if (table.getn(activeOutfitList) > 0) then
	
		-- set the names of any equipped outfits
		for j = 1, table.getn(activeOutfitList) do
		
			curOutfit = Wardrobe_Config[WD_realmID][WD_charID].Outfit[activeOutfitList[j]].OutfitName;
			
			-- don't match special outfits
			if (string.sub(curOutfit, 1, 1) ~= "#") then
			
				if (outfitText == nil) then
					outfitText = curOutfit;
				else
					outfitText = outfitText..", "..curOutfit;
				end
			end
		end
	end
	
	-- display the outfit in colour only if the user has selected
	if (TitanGetVar(WARDROBE_TITAN_ID, "ShowColoredText")) then
		
		if (outfitText == nil) then
		
			-- show red if we are not wearing an outfit
			outfitText = TitanUtils_GetRedText(WARDROBE_TITAN_NO_OUTFIT);		   
		else
			
			-- show green if we are wearing an outfit
			outfitText = TitanUtils_GetGreenText(outfitText);
		end
	else
	
		if (outfitText == nil) then
		
			-- we aren't wearing an outfit
			outfitText = WARDROBE_TITAN_NO_OUTFIT;		  
		end
		
		-- no colour
		outfitText = TitanUtils_GetHighlightText(outfitText);
	end
	
	-- show / hide the minimap icon
	if (TitanGetVar(WARDROBE_TITAN_ID, "ShowMinimapIcon")) then
		Wardrobe_Config[WD_realmID][WD_charID].MinimapButtonVisible = 1;
		Wardrobe.IconFrame:Show();
	else
		Wardrobe_Config[WD_realmID][WD_charID].MinimapButtonVisible = 0;
		Wardrobe.IconFrame:Hide();
	end
	
	-- another kludge - set the parent to determine whether we have a small or large menu
	if (TitanGetVar(WARDROBE_TITAN_ID, "SmallMenu")) then
		-- small outfit menu
		Wardrobe.Popup:SetParent(this:GetParent());
	else
		-- large outfit menu
		Wardrobe.Popup:SetParent(nil);
	end
	
	return labelText, outfitText;
end
Wardrobe_TitanPanelButton_GetButtonText = Wardrobe.TitanPanelButton_GetButtonText;

function Wardrobe.TitanPanelButton_GetTooltipText()
	return WARDROBE_TITAN_TOOLTIP_TEXT;
end
Wardrobe_TitanPanelButton_GetTooltipText = Wardrobe.TitanPanelButton_GetTooltipText;

function TitanPanelRightClickMenu_PrepareWardrobeMenu()

	TitanPanelRightClickMenu_AddTitle(TitanPlugins[WARDROBE_TITAN_ID].menuText);
	
	-- show the "hide minimap icon"
	TitanPanelRightClickMenu_AddToggleVar(WARDROBE_TITAN_MENU_SHOW_MINIMAP_ICON, WARDROBE_TITAN_ID, "ShowMinimapIcon");
	
	TitanPanelRightClickMenu_AddSpacer();
	
	-- show the "Small outfit menu" option
	TitanPanelRightClickMenu_AddToggleVar(WARDROBE_TITAN_MENU_SMALL_MENU, WARDROBE_TITAN_ID, "SmallMenu");

	-- standard titan menu stuff
	TitanPanelRightClickMenu_AddSpacer();

	TitanPanelRightClickMenu_AddToggleIcon(WARDROBE_TITAN_ID);
	TitanPanelRightClickMenu_AddToggleLabelText(WARDROBE_TITAN_ID);
	TitanPanelRightClickMenu_AddToggleColoredText(WARDROBE_TITAN_ID);

	TitanPanelRightClickMenu_AddSpacer();

	TitanPanelRightClickMenu_AddCommand(TITAN_PANEL_MENU_HIDE, WARDROBE_TITAN_ID, TITAN_PANEL_MENU_FUNC_HIDE);
end

function Wardrobe.TitanPanelButton_OnClick(button)
	
	-- show the wardrobe menu on left clicks
	if ( button == "LeftButton" ) then
		
		-- show the wardrobe menu
		Wardrobe.ColorCycle_UIPopupMenu(true);
		Wardrobe.ShowUIMenu();
		
		-- position it
		local position = TitanUtils_GetRealPosition(WARDROBE_TITAN_ID);
		local horizOffset = Wardrobe.Popup:GetWidth() / 2 + this:GetWidth() / 2;
		
		if (position == TITAN_PANEL_PLACE_TOP) then 
			Wardrobe.Popup:SetPoint("TOPRIGHT", this:GetName(), "BOTTOMLEFT", horizOffset, 0);
		else
			Wardrobe.Popup:SetPoint("TOPRIGHT", this:GetName(), "TOPLEFT", horizOffset, Wardrobe.Popup:GetHeight());
		end
		
	end
	
	TitanPanelButton_OnClick(button, 1);
end

function Wardrobe.TitanPanelButton_OnEnter()
	if (Wardrobe_Config.MustClickUIButton) then
		TitanPanelButton_OnEnter();
	else
		Wardrobe.TitanPanelButton_OnClick("LeftButton");
	end
end

